.BG
.FN bkde
.TL
Compute a Binned Kernel Density Estimate
.DN
Returns x and y coordinates of the binned
kernel density estimate of the probability
density of the data.  
.CS
bkde (x,kernel="normal",canonical=F,bandwidth,
      gridsize=401,range.x=range(x),truncate=T)
.RA
.AG x
vector of observations from the distribution whose density is to
be estimated.
Missing values are not allowed.
.AG bandwidth
the kernel bandwidth smoothing parameter.
Larger values of `bandwidth' make smoother estimates,
smaller values of `bandwidth' make less smooth estimates.
.OA
.AG kernel
character string which determines the smoothing kernel.
`kernel' can be:
.br
`"normal"' - the Gaussian density function (the default).
.br
`"box"' - a rectangular box.
.br
`"epanech"' - the centred beta(2,2) density.
.br
`"biweight"' - the centred beta(3,3) density.
.br
`"triweight"' - the centred beta(4,4) density.
.AG canonical 
logical flag: if TRUE, canonically scaled kernels are used.
.AG gridsize
the number of equally spaced points at which to estimate
the density.
.AG range.x
vector containing the minimum and maximum values of `x'
at which to compute the estimate.
The default is the minimum and maximum data values.
.AG truncate
logical flag: if `TRUE', data with `x' values outside the
range specified by `range.x' are ignored.
.RT
a list containing the following components:
.RC x
vector of sorted `x' values at which the estimate was computed.
.RC y
vector of density estimates
at the corresponding `x'.
.DT
This is the binned approximation to the ordinary kernel density estimate.
Linear binning is used to obtain the bin counts.  
For each `x' value in the sample, the kernel is
centered on that `x' and the heights of the kernel at each datapoint are summed.
This sum, after a normalization, is the corresponding `y' value in the output.
.SP
.SH BACKGROUND
Density estimation is a smoothing operation.
Inevitably there is a trade-off between bias in the estimate and the
estimate's variability: large bandwidths will produce smooth estimates that
may hide local features of the density; small bandwidths may introduce
spurious bumps into the estimate.
.SH REFERENCES
Wand, M. P. and Jones, M. C. (1995).
.ul
Kernel Smoothing.
Chapman and Hall, London.
.SA
`density', `dpik', `hist', `ksmooth'.
.EX
x <- geyser$duration
est <- bkde(x,bandwidth=0.25)
plot(est,type="l")
.KW distribution
.KW smooth
.WR
