.BG
.FN bkfe
.TL
Compute a Binned Kernel Functional Estimate 
.DN
Returns an estimate of a binned approximation to
the kernel estimate of the specified density functional. 
The kernel is the standard normal density.
.CS
bkfe(x, drv, bandwidth, gridsize=401, range.x=range(x),
     binned=F, truncate=F)
.RA
.AG x
vector of observations from the distribution whose density is to
be estimated.
Missing values are not allowed.
.AG drv
order of derivative in the density functional. Must be a
non-negative even integer.
.AG bandwidth
the kernel bandwidth smoothing parameter.
.OA
.AG gridsize
the number of equally-spaced points over which binning is
performed.
.AG range.x
vector containing the minimum and maximum values of `x'
at which to compute the estimate.
The default is the minimum and maximum data values.
.AG binned
logical flag: if `TRUE', then `x' and `y' are taken to be grid counts
rather than raw data.
.AG truncate
logical flag: if `TRUE', data with `x' values outside the
range specified by `range.x' are ignored.
.RT
the estimated functional.
.DT
The density functional of order `drv' is the integral of the
product of the density and its `drv'th derivative. 
The kernel estimates
of such quantities are computed using a binned implementation,
and the kernel is the standard normal density.
.SH BACKGROUND
Estimates of this type were proposed by Sheather and
Jones (1991).
.SH REFERENCES
Sheather, S. J. and Jones, M. C. (1991).
A reliable data-based bandwidth selection method for
kernel density estimation.
.ul
Journal of the Royal Statistical Society, Series B,
\fB53\fR, 683-690.
.PP
Wand, M. P. and Jones, M. C. (1995).
.ul
Kernel Smoothing.
Chapman and Hall, London.
.EX
x <- geyser$duration
est <- bkfe(x,drv=4,bandwidth=0.3)
.KW smooth 
.WR
