.BG
.FN dpik
.TL
Select a Bandwidth for Kernel Density Estimation
.DN
Use direct plug-in methodology to select the bandwidth
of a kernel density estimate.
.CS
dpik(x, scalest="minim", level=2, kernel="normal",   
     canonical=F, gridsize=401, range.x=range(x), 
     truncate=F)
.RA
.AG x
vector containing the sample on which the
kernel density estimate is to be constructed.
.OA
.AG scalest
estimate of scale.
.sp
 `"stdev"' - standard deviation is used.
.sp
 `"iqr"' - inter-quartile range divided by 1.349 is used.
.sp
 `"minim"' - minimum of `"stdev"' and `"iqr"' is used.
.AG level
number of levels of functional estimation used in the
plug-in rule.
.AG kernel
character string which determines the smoothing kernel.
`kernel' can be:
.br
`"normal"' - the Gaussian density function (the default).
.br
`"box"' - a rectangular box.
.br
`"epanech"' - the centred beta(2,2) density.
.br
`"biweight"' - the centred beta(3,3) density.
.br
`"triweight"' - the centred beta(4,4) density.
.AG canonical
logical flag: if `TRUE', canonically scaled kernels are used
.AG gridsize
the number of equally-spaced points over which binning is 
performed to obtain kernel functional approximation. 
.AG range.x
vector containing the minimum and maximum values of `x'
at which to compute the estimate.
The default is the minimum and maximum data values.
.AG truncate
logical flag: if `TRUE', data with `x' values outside the
range specified by `range.x' are ignored.
.RT
the selected bandwidth.
.DT
The direct plug-in approach, where unknown functionals
that appear in expressions for the asymptotically
optimal bandwidths
are replaced by kernel estimates, is used.
The normal distribution is used to provide an
initial estimate.
.SH BACKGROUND
This method for selecting the bandwidth of a kernel
density estimate was proposed by Sheather and
Jones (1991)
and is
described in Section 3.6 of Wand and Jones (1995). 
.SH REFERENCES
Sheather, S. J. and Jones, M. C. (1991).
A reliable data-based bandwidth selection method for
kernel density estimation.
.ul
Journal of the Royal Statistical Society, Series B,
\fB53\fR, 683-690.
.PP
Wand, M. P. and Jones, M. C. (1995).
.ul
Kernel Smoothing.
Chapman and Hall, London.
.SA
`bkde', `density', `ksmooth'
.EX 
x <- geyser$duration
h <- dpik(x)
est <- bkde(x,bandwidth=h)
plot(est,type="l")
.KW smooth 
.WR
