.BG
.FN dpill
.TL
Select a Bandwidth for Local Linear Regression
.DN
Use direct plug-in methodology to select the bandwidth
of a local linear Gaussian kernel regression estimate, as described
by Ruppert, Sheather and Wand (1995). 
.CS
dpill(x, y, blockmax=5, divisor=20, trim=0.01, proptrun=0.05, 
      gridsize=401, range.x=<<see below>>, truncate=T)
.RA
.AG x
vector of x data.
Missing values are not accepted.
.AG y
vector of y data.
This must be same length as `x', and
missing values are not accepted.
.OA
.AG blockmax
the maximum number of blocks of the data for construction
of an initial parametric estimate. 
.AG divisor
the value that the sample size is divided by to determine
a lower limit on the number of blocks of the data for
construction of an initial parametric estimate.
.AG trim
the proportion of the sample trimmed from each end in the
`x' direction before application of the plug-in methodology.
.AG proptrun
the proportion of the range of `x' at each end truncated in the
functional estimates.
.AG gridsize
number of equally-spaced grid points over which the
function is to be estimated.
.AG range.x
vector containing the minimum and maximum values of `x' at which to
compute the estimate.
For density estimation the default is the minimum and maximum data values
with 5% of the range added to each end.
For regression estimation the default is the minimum and maximum data values.
.AG truncate
logical flag: if `TRUE', data with `x' values outside the range specified
by `range.x' are ignored.
.RT
the selected bandwidth.
.DT
The direct plug-in approach, where unknown functionals
that appear in expressions for the asymptotically
optimal bandwidths
are replaced by kernel estimates, is used.
The kernel is the standard normal density.
Least squares quartic fits over blocks of data are used to 
obtain an initial estimate. Mallow's Cp is used to select
the number of blocks.
.SH WARNING
If there are severe irregularities (i.e. outliers, sparse regions)
in the `x' values then the local polynomial smooths required for the
bandwidth selection algorithm may become degenerate and the function
will crash. Outliers in the `y' direction may lead to deterioration
of the quality of the selected bandwidth.
.SH REFERENCES
Ruppert, D., Sheather, S. J. and Wand, M. P. (1995).
An effective bandwidth selector for local least squares
regression.
.ul
Journal of the American Statistical Association,
\fB90\fR, 1257-1270.
.PP
Wand, M. P. and Jones, M. C. (1995).
.ul
Kernel Smoothing.
Chapman and Hall, London.
.SA
`ksmooth', `locpoly'.
.EX
x <- geyser$duration
y <- geyser$waiting
plot(x,y)
h <- dpill(x,y)
fit <- locpoly(x,y,bandwidth=h)
lines(fit)
.KW smooth 
.WR
